import { http } from '@/utils/http'
import type { AddressItem, AddressParams } from '@/types/address'

type EditAddressSuccessParams = { id: string }

/**
 * 添加收货地址
 * @param data - 收货地址信息
 */
export const postMemberAddressAPI = (data: AddressParams) => {
  return http<EditAddressSuccessParams>({
    url: '/member/address',
    method: 'POST',
    data,
  })
}

/**
 * 获取收货地址列表
 */
export const getMemberAddressAPI = () => {
  return http<AddressItem[]>({
    url: '/member/address',
    method: 'GET',
  })
}

/**
 * 获取收货地址详情
 * @param id - 收货地址 ID
 */
export const getAddressDetailAPI = (id: string) => {
  return http<AddressItem>({
    url: `/member/address/${id}`,
    method: 'GET',
  })
}

/**
 * 修改收货地址
 * @param id - 收货地址 ID
 * @param data - 收货地址信息
 */
export const putMemberAddressAPI = (id: string, data: AddressParams) => {
  return http<EditAddressSuccessParams>({
    url: `/member/address/${id}`,
    method: 'PUT',
    data,
  })
}

/**
 * 删除收货地址
 * @param id - 收货地址 ID
 */
export const deleteMemberAddressAPI = (id: string) => {
  return http<EditAddressSuccessParams>({
    url: `/member/address/${id}`,
    method: 'DELETE',
  })
}
