import type { CartItem } from '@/types/cart'
import { http } from '@/utils/http'

/**
 * 加入购物车
 */
export const postMemberCartAPI = (data: { skuId: string; count: number }) => {
  return http({
    url: '/member/cart',
    method: 'POST',
    data,
  })
}

/**
 * 获取购物车列表
 */
export const getMemberCartAPI = () => {
  return http<CartItem[]>({
    url: '/member/cart',
    method: 'GET',
  })
}

/**
 * 删除购物车商品
 */
export const deleteMemberCartAPI = (data: { ids: string[] }) => {
  return http({
    url: '/member/cart',
    method: 'DELETE',
    data,
  })
}

/**
 * 修改购物车商品数量
 */
type PutMemberCartAPIParams = {
  /** 是否选中 */
  selected?: boolean
  /** 商品数量 */
  count?: number
}
export const putMemberCartAPI = (skuId: string, data: PutMemberCartAPIParams) => {
  return http({
    url: `/member/cart/${skuId}`,
    method: 'PUT',
    data,
  })
}

/**
 * 修改购物车商品全选状态
 */
export const putMemberCartSelectedAPI = (data: { selected: boolean }) => {
  return http({
    url: '/member/cart/selected',
    method: 'PUT',
    data,
  })
}
