// 关键帧对象类型
export interface Keyframe {
  offset?: number // 关键帧的偏移，范围[0-1]
  ease?: string // 动画缓动函数
  transformOrigin?: string // 基点位置
  backgroundColor?: string // 背景颜色
  opacity?: number // 不透明度
  width?: string // 宽度
  height?: string // 高度
  left?: string // 左边位置
  top?: string // 顶边位置
  right?: string // 右边位置
  bottom?: string // 底边位置
  matrix?: number[] // 变换矩阵
  matrix3d?: number[] // 三维变换矩阵
  rotate?: number // 旋转
  rotate3d?: number[] // 三维旋转
  rotateX?: number // X 方向旋转
  rotateY?: number // Y 方向旋转
  rotateZ?: number // Z 方向旋转
  scale?: number[] // 缩放
  scale3d?: number[] // 三维缩放
  scaleX?: number // X 方向缩放
  scaleY?: number // Y 方向缩放
  scaleZ?: number // Z 方向缩放
  skew?: number[] // 倾斜
  skewX?: number // X 方向倾斜
  skewY?: number // Y 方向倾斜
  translate?: number[] // 位移
  translate3d?: number[] // 三维位移
  translateX?: number // X 方向位移
  translateY?: number // Y 方向位移
  translateZ?: number // Z 方向位移
  color?: string // 文字颜色
  [key: string]: any // 其他可能的CSS属性
}

// 滚动时间线参数
export interface ScrollTimeline {
  scrollSource: string // 滚动元素的选择器
  orientation?: 'horizontal' | 'vertical' // 滚动方向
  startScrollOffset: number // 开始驱动动画的滚动偏移量
  endScrollOffset: number // 停止驱动动画的滚动偏移量
  timeRange: number // 滚动范围映射的时间长度
}

// 清除动画选项
export interface ClearAnimationOptions {
  opacity?: boolean
  backgroundColor?: boolean
  width?: boolean
  height?: boolean
  left?: boolean
  right?: boolean
  top?: boolean
  bottom?: boolean
  rotate?: boolean
  rotateX?: boolean
  rotateY?: boolean
  rotateZ?: boolean
  scale?: boolean
  scaleX?: boolean
  scaleY?: boolean
  scaleZ?: boolean
  translate?: boolean
  translateX?: boolean
  translateY?: boolean
  translateZ?: boolean
  [key: string]: boolean | undefined
}

// 动画方法类型
export interface AnimationMethods {
  /**
   * 关键帧动画
   * @param selector 选择器
   * @param keyframes 关键帧信息
   * @param duration 动画持续时长（毫秒）
   * @param callback 动画完成后的回调函数
   */
  animate(selector: string, keyframes: Keyframe[], duration: number, callback?: () => void): void

  /**
   * 滚动驱动的动画
   * @param selector 选择器
   * @param keyframes 关键帧信息
   * @param duration 动画持续时长（毫秒）
   * @param scrollTimeline 滚动时间线参数
   */
  animate(
    selector: string,
    keyframes: Keyframe[],
    duration: number,
    scrollTimeline: ScrollTimeline,
  ): void

  /**
   * 清除动画
   * @param selector 选择器
   * @param options 需要清除的属性，不填写则全部清除
   * @param callback 清除完成后的回调函数
   */
  clearAnimation(selector: string, options?: ClearAnimationOptions, callback?: () => void): void
}
